@@ -99,6 +99,7 @@ pref("browser.enable_automatic_image_resizing", false);
 pref("signon.rememberSignons", true);
 pref("signon.expireMasterPassword", false);
 pref("signon.SignonFileName", "signons.txt");
+pref("signon.SignonFileName2", "signons2.txt");
 pref("signon.autofillForms", true);
 
 // use system colours
@@ -126,7 +127,7 @@ pref("general.useragent.locale", "en");
 // spellcheck
 // pref("extensions.spellcheck.inline.max-misspellings", -1);
 // 0: disabled, 1: only textareas, 2: check textareas and single-line input fields
-pref("layout.spellcheckDefault", 1);
+pref("layout.spellcheckDefault", 0);
 pref("spellchecker.dictionary", "");
 
 // print settings
@@ -137,6 +138,8 @@ pref("print.show_print_progress", true);
 pref("print.printer_list", "");
 pref("postscript.enabled", true);
 pref("postscript.cups.enabled", false);
+// deactivate PAPI too (will be added in https://bugzilla.mozilla.org/show_bug.cgi?id=317450)
+pref("postscript.papi.enabled", false);
 
 // sites stealthly storing unlimited amount of data? no thanks
 pref("dom.storage.enabled", false);
@@ -146,3 +149,14 @@ pref("general.warnOnAboutConfig", true);
 
 // enable negotiate extension
 pref("network.negotiate-auth.trusted-uris", "https://");
+
+// JS annoyances
+pref("dom.disable_window_flip", true);
+
+// Whether delete and backspace should immediately delete characters not
+// visually adjacent to the caret, or adjust the visual position of the caret
+// on the first keypress and delete the character on a second keypress
+// (added in bug https://bugzilla.mozilla.org/show_bug.cgi?id=328834)
+// set to true for parity with gtk entries
+pref("bidi.edit.delete_immediately", true);
+
