@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoPrintSession.cpp 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: GeckoPrintSession.cpp 7081 2007-06-14 12:17:29Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -98,13 +98,17 @@ GeckoPrintSession::GetSourceFile (nsACString &aSource)
 }
 
 nsresult
-GeckoPrintSession::SetSettings (GtkPrintSettings *aSettings,
+GeckoPrintSession::SetSettings (nsIPrintSettings *aPrintSettings,
+                                GtkPrintSettings *aSettings,
 				GtkPageSetup *aPageSetup,
 				GtkPrinter *aPrinter)
 {
-  NS_ASSERTION (!mSettings && !mPageSetup && !mPrinter, "Already have settings!");
+  NS_ASSERTION (!mPrintSettings && !mSettings && !mPageSetup && !mPrinter, "Already have settings!");
 
+  NS_ENSURE_ARG (aPrintSettings);
   NS_ENSURE_ARG (aSettings);
+
+  mPrintSettings = aPrintSettings;
   mSettings = (GtkPrintSettings *) g_object_ref (aSettings);
 
   NS_ENSURE_ARG (aPageSetup);
@@ -562,10 +566,15 @@ GeckoPrintSession::GetProcessCanceledByUser (PRBool *aProcessCanceledByUser)
   *aProcessCanceledByUser = mCancelled;
   return NS_OK;
 }
+
 NS_IMETHODIMP
 GeckoPrintSession::SetProcessCanceledByUser (PRBool aProcessCanceledByUser)
 {
   mCancelled = aProcessCanceledByUser;
+  if (mPrintSettings) {
+    mPrintSettings->SetIsCancelled (aProcessCanceledByUser);
+  }
+
   return NS_OK;
 }
 
