@@ -1,6 +1,6 @@
 /*
- *  Copyright © 2003, 2004  Marco Pesenti Gritti
- *  Copyright © 2003, 2004, 2005  Christian Persch
+ *  Copyright (C) 2003, 2004  Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004, 2005  Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: egg-editable-toolbar.c 7115 2007-07-03 21:29:09Z jhaitsma $
  */
 
 #include "config.h"
@@ -44,14 +44,15 @@
 #include <gtk/gtktoolitem.h>
 #include <gtk/gtktoolbutton.h>
 #include <gtk/gtkseparatortoolitem.h>
+#include <gtk/gtkicontheme.h>
 #include <glib/gi18n.h>
 #include <string.h>
 
-static void egg_editable_toolbar_class_init	(EggEditableToolbarClass *klass);
-static void egg_editable_toolbar_init		(EggEditableToolbar *etoolbar);
+static GdkPixbuf * new_separator_pixbuf         (void);
 
 #define MIN_TOOLBAR_HEIGHT 20
 #define EGG_ITEM_NAME      "egg-item-name"
+#define STOCK_DRAG_MODE    "stock_drag-mode"
 
 static const GtkTargetEntry dest_drag_types[] = {
   {EGG_TOOLBAR_ITEM_TYPE, GTK_TARGET_SAME_APP, 0},
@@ -75,8 +76,6 @@ enum
 
 static guint egg_editable_toolbar_signals[LAST_SIGNAL] = { 0 };
 
-static GObjectClass *parent_class = NULL;
-
 #define EGG_EDITABLE_TOOLBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EGG_TYPE_EDITABLE_TOOLBAR, EggEditableToolbarPrivate))
 
 struct _EggEditableToolbarPrivate
@@ -101,32 +100,7 @@ struct _EggEditableToolbarPrivate
   GtkToolItem *dnd_toolitem;
 };
 
-GType
-egg_editable_toolbar_get_type (void)
-{
-  static GType type = 0;
-
-  if (G_UNLIKELY (type == 0))
-    {
-      const GTypeInfo our_info = {
-	sizeof (EggEditableToolbarClass),
-	NULL,			/* base_init */
-	NULL,			/* base_finalize */
-	(GClassInitFunc) egg_editable_toolbar_class_init,
-	NULL,
-	NULL,			/* class_data */
-	sizeof (EggEditableToolbar),
-	0,			/* n_preallocs */
-	(GInstanceInitFunc) egg_editable_toolbar_init
-      };
-
-      type = g_type_register_static (GTK_TYPE_VBOX,
-				     "EggEditableToolbar",
-				     &our_info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (EggEditableToolbar, egg_editable_toolbar, GTK_TYPE_VBOX);
 
 static int
 get_dock_position (EggEditableToolbar *etoolbar,
@@ -460,6 +434,7 @@ configure_item_cursor (GtkToolItem *item,
       if (priv->edit_mode > 0)
         {
           GdkCursor *cursor;
+          GdkPixbuf *pixbuf = NULL;
           
           cursor = gdk_cursor_new (GDK_HAND2);
           gdk_window_set_cursor (widget->window, cursor);
@@ -467,6 +442,64 @@ configure_item_cursor (GtkToolItem *item,
 
           gtk_drag_source_set (widget, GDK_BUTTON1_MASK, dest_drag_types,
                                G_N_ELEMENTS (dest_drag_types), GDK_ACTION_MOVE);
+          if (GTK_IS_SEPARATOR_TOOL_ITEM (item))
+            {
+              pixbuf = new_separator_pixbuf ();
+            }
+          else
+            {
+              char *icon_name=NULL;
+              char *stock_id=NULL;
+              GtkAction *action;
+              char *name;
+
+              name = g_object_get_data (G_OBJECT (widget), EGG_ITEM_NAME);
+              action = name ? find_action (etoolbar, name) : NULL;
+
+              if (action)
+                {
+                   g_object_get (action,
+                                 "icon-name", &icon_name,
+                                 "stock-id", &stock_id,
+                                 NULL);
+                }
+              if (icon_name)
+                {
+                  GdkScreen *screen;
+                  GtkIconTheme *icon_theme;
+                  GtkSettings *settings;
+                  gint width, height;
+
+                  screen = gtk_widget_get_screen (widget);
+                  icon_theme = gtk_icon_theme_get_for_screen (screen);
+                  settings = gtk_settings_get_for_screen (screen);
+
+                  if (!gtk_icon_size_lookup_for_settings (settings,
+                                                          GTK_ICON_SIZE_LARGE_TOOLBAR,
+                                                          &width, &height))
+                    {
+                      width = height = 24;
+                    }
+
+                  pixbuf = gtk_icon_theme_load_icon (icon_theme, icon_name,
+                                                     MIN (width, height), 0, NULL);
+                }
+              else if (stock_id)
+                {		 
+                  pixbuf = gtk_widget_render_icon (widget, stock_id,
+	                                           GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+                }
+              g_free (icon_name);
+              g_free (stock_id);
+            }
+
+          if (G_UNLIKELY (!pixbuf))
+            {
+              return;
+            }
+          gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
+          g_object_unref (pixbuf);
+
         }
       else
         {
@@ -531,9 +564,6 @@ action_sensitive_cb (GtkAction   *action,
   EggEditableToolbar *etoolbar = EGG_EDITABLE_TOOLBAR
     (gtk_widget_get_ancestor (GTK_WIDGET (item), EGG_TYPE_EDITABLE_TOOLBAR));
 
-  if (etoolbar == NULL)
-    return;
-
   if (etoolbar->priv->edit_mode > 0)
     {
       gtk_widget_set_sensitive (GTK_WIDGET (item), TRUE);
@@ -1353,7 +1383,7 @@ egg_editable_toolbar_dispose (GObject *object)
       priv->model = NULL;
     }
 
-  G_OBJECT_CLASS (parent_class)->dispose (object);
+  G_OBJECT_CLASS (egg_editable_toolbar_parent_class)->dispose (object);
 }
 
 static void
@@ -1361,7 +1391,7 @@ egg_editable_toolbar_set_ui_manager (EggEditableToolbar *etoolbar,
 				     GtkUIManager       *manager)
 {
   static const GtkActionEntry actions[] = {
-    { "MoveToolItem", NULL, N_("_Move on Toolbar"), NULL,
+    { "MoveToolItem", STOCK_DRAG_MODE, N_("_Move on Toolbar"), NULL,
       N_("Move the selected item on the toolbar"), G_CALLBACK (move_item_cb) },
     { "RemoveToolItem", GTK_STOCK_REMOVE, N_("_Remove from Toolbar"), NULL,
       N_("Remove the selected item from the toolbar"), G_CALLBACK (remove_item_cb) },
@@ -1525,8 +1555,6 @@ egg_editable_toolbar_class_init (EggEditableToolbarClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  parent_class = g_type_class_peek_parent (klass);
-
   object_class->dispose = egg_editable_toolbar_dispose;
   object_class->set_property = egg_editable_toolbar_set_property;
   object_class->get_property = egg_editable_toolbar_get_property;
