@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,14 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-toolbar-editor.c,v 1.35 2006/09/13 11:34:20 chpe Exp $
+ *  $Id: egg-toolbar-editor.c 7115 2007-07-03 21:29:09Z jhaitsma $
  */
 
 #include "config.h"
 
 #include "egg-toolbar-editor.h"
 #include "egg-editable-toolbar.h"
-#include "eggintl.h"
 
 #include <string.h>
 #include <libxml/tree.h>
@@ -35,6 +34,7 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 static const GtkTargetEntry dest_drag_types[] = {
   {EGG_TOOLBAR_ITEM_TYPE, GTK_TARGET_SAME_APP, 0},
@@ -44,8 +44,7 @@ static const GtkTargetEntry source_drag_types[] = {
   {EGG_TOOLBAR_ITEM_TYPE, GTK_TARGET_SAME_APP, 0},
 };
 
-static void egg_toolbar_editor_class_init	(EggToolbarEditorClass *klass);
-static void egg_toolbar_editor_init		(EggToolbarEditor *t);
+
 static void egg_toolbar_editor_finalize         (GObject *object);
 static void update_editor_sheet                 (EggToolbarEditor *editor);
 
@@ -56,8 +55,6 @@ enum
   PROP_TOOLBARS_MODEL
 };
 
-static GObjectClass *parent_class = NULL;
-
 #define EGG_TOOLBAR_EDITOR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EGG_TYPE_TOOLBAR_EDITOR, EggToolbarEditorPrivate))
 
 struct EggToolbarEditorPrivate
@@ -71,32 +68,7 @@ struct EggToolbarEditorPrivate
   GList     *factory_list;
 };
 
-GType
-egg_toolbar_editor_get_type (void)
-{
-  static GType type = 0;
-
-  if (G_UNLIKELY (type == 0))
-    {
-      const GTypeInfo our_info = {
-	sizeof (EggToolbarEditorClass),
-	NULL,			/* base_init */
-	NULL,			/* base_finalize */
-	(GClassInitFunc) egg_toolbar_editor_class_init,
-	NULL,
-	NULL,			/* class_data */
-	sizeof (EggToolbarEditor),
-	0,			/* n_preallocs */
-	(GInstanceInitFunc) egg_toolbar_editor_init
-      };
-
-      type = g_type_register_static (GTK_TYPE_VBOX,
-				     "EggToolbarEditor",
-				     &our_info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (EggToolbarEditor, egg_toolbar_editor, GTK_TYPE_VBOX);
 
 static gint
 compare_items (gconstpointer a,
@@ -224,8 +196,6 @@ egg_toolbar_editor_class_init (EggToolbarEditorClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  parent_class = g_type_class_peek_parent (klass);
-
   object_class->finalize = egg_toolbar_editor_finalize;
   object_class->set_property = egg_toolbar_editor_set_property;
   object_class->get_property = egg_toolbar_editor_get_property;
@@ -268,7 +238,7 @@ egg_toolbar_editor_finalize (GObject *object)
   g_list_free (editor->priv->actions_list);
   g_list_free (editor->priv->factory_list);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (egg_toolbar_editor_parent_class)->finalize (object);
 }
 
 GtkWidget *
@@ -362,12 +332,43 @@ event_box_realize_cb (GtkWidget *widget, GtkImage *icon)
     {
       gchar *stock_id;
       GdkPixbuf *pixbuf;
+
       gtk_image_get_stock (icon, &stock_id, NULL);
       pixbuf = gtk_widget_render_icon (widget, stock_id,
 	                               GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
       gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
       g_object_unref (pixbuf);
     }
+  else if (type == GTK_IMAGE_ICON_NAME)
+    {
+      const gchar *icon_name;
+      GdkScreen *screen;
+      GtkIconTheme *icon_theme;
+      GtkSettings *settings;
+      gint width, height;
+      GdkPixbuf *pixbuf;
+
+      gtk_image_get_icon_name (icon, &icon_name, NULL);
+      screen = gtk_widget_get_screen (widget);
+      icon_theme = gtk_icon_theme_get_for_screen (screen);
+      settings = gtk_settings_get_for_screen (screen);
+
+      if (!gtk_icon_size_lookup_for_settings (settings,
+                                              GTK_ICON_SIZE_LARGE_TOOLBAR,
+					      &width, &height))
+        {
+	  width = height = 24;
+	}
+
+      pixbuf = gtk_icon_theme_load_icon (icon_theme, icon_name,
+                                         MIN (width, height), 0, NULL);
+      if (G_UNLIKELY (!pixbuf))
+        return;
+
+      gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
+      g_object_unref (pixbuf);
+
+    }
   else if (type == GTK_IMAGE_PIXBUF)
     {
       GdkPixbuf *pixbuf = gtk_image_get_pixbuf (icon);
@@ -427,8 +428,7 @@ editor_create_item_from_name (EggToolbarEditor *editor,
 {
   GtkWidget *item;
   const char *item_name;
-  const char *stock_id;
-  const char *short_label;
+  char *short_label;
   const char *collate_key;
   
   if (strcmp (name, "_separator") == 0)
@@ -437,36 +437,42 @@ editor_create_item_from_name (EggToolbarEditor *editor,
       
       icon = _egg_editable_toolbar_new_separator_image ();
       short_label = _("Separator");
-      item_name = strdup (name);
+      item_name = g_strdup (name);
       collate_key = g_utf8_collate_key (short_label, -1);
       item = editor_create_item (editor, GTK_IMAGE (icon), 
                                  short_label, drag_action);
     }
   else
     {
-      GValue value = { 0, };
       GtkAction *action;
       GtkWidget *icon;
+      char *stock_id, *icon_name = NULL;
       
       action = find_action (editor, name);
       g_return_val_if_fail (action != NULL, NULL);
 
-      g_value_init (&value, G_TYPE_STRING);
-      g_object_get_property (G_OBJECT (action), "stock_id", &value);
-      stock_id = g_value_get_string (&value);
-      icon = gtk_image_new_from_stock (stock_id ? stock_id : GTK_STOCK_DND,
-                                       GTK_ICON_SIZE_LARGE_TOOLBAR);
-      g_value_unset (&value);
-      
-      g_value_init (&value, G_TYPE_STRING);
-      g_object_get_property (G_OBJECT (action), "short_label", &value);
-      short_label = g_value_get_string (&value);
+      g_object_get (action,
+                    "icon-name", &icon_name,
+                    "stock-id", &stock_id,
+		    "short-label", &short_label,
+		    NULL);
 
-      item_name = strdup (name);
+      /* This is a workaround to catch named icons. */
+      if (icon_name)
+        icon = gtk_image_new_from_icon_name (icon_name,
+	                                     GTK_ICON_SIZE_LARGE_TOOLBAR);
+      else
+        icon = gtk_image_new_from_stock (stock_id ? stock_id : GTK_STOCK_DND,
+                                         GTK_ICON_SIZE_LARGE_TOOLBAR);
+
+      item_name = g_strdup (name);
       collate_key = g_utf8_collate_key (short_label, -1);
       item = editor_create_item (editor, GTK_IMAGE (icon),
                                  short_label, drag_action);
-      g_value_unset (&value);
+
+      g_free (short_label);
+      g_free (stock_id);
+      g_free (icon_name);
     }
   
   g_object_set_data_full (G_OBJECT (item), "egg-collate-key",
