@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-stock-icons.c 6830 2007-01-18 12:36:08Z lferrett $
+ *  $Id: ephy-stock-icons.c 7119 2007-07-09 16:37:50Z chpe $
  */
 
 #include "config.h"
@@ -37,16 +37,13 @@ ephy_stock_icons_init (void)
 	GtkIconSource *icon_source;
 	int i;
 
-	static const char *icon_theme_items[] =
+	const char *icon_theme_items[] =
 	{
 		STOCK_NEW_TAB,
 		STOCK_NEW_WINDOW,
 		STOCK_SEND_MAIL,
 		STOCK_ADD_BOOKMARK,
 		STOCK_PRINT_SETUP,
-		STOCK_LOCK_INSECURE,
-		STOCK_LOCK_SECURE,
-		STOCK_LOCK_BROKEN,
 	};
 
 	static const GtkStockItem items[] =
@@ -56,7 +53,10 @@ ephy_stock_icons_init (void)
 		{ EPHY_STOCK_BOOKMARK,  N_("Bookmark"),         0, 0, NULL },
 		{ EPHY_STOCK_BOOKMARKS, N_("Bookmarks"),	0, 0, NULL },
 		{ EPHY_STOCK_ENTRY,	N_("Address Entry"),	0, 0, NULL },
-		{ EPHY_STOCK_DOWNLOAD,	N_("_Download"),	0, 0, NULL }
+		{ EPHY_STOCK_DOWNLOAD,	N_("_Download"),	0, 0, NULL },
+		{ STOCK_LOCK_INSECURE },
+		{ STOCK_LOCK_SECURE },
+		{ STOCK_LOCK_BROKEN }
 	};
 
 	factory = gtk_icon_factory_new ();
