@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  $Id: ephy-find-toolbar.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-find-toolbar.c 7021 2007-05-04 20:00:04Z diegoe $
  */
 
 #include "config.h"
@@ -257,6 +257,14 @@ entry_key_press_event_cb (GtkEntry *entry,
 	{
 		handled = ephy_embed_find_activate_link (get_find (toolbar), event->state);
 	}
+	else if ((event->state & mask) == GDK_SHIFT_MASK &&
+		 (event->keyval == GDK_Return ||
+		  event->keyval == GDK_KP_Enter ||
+		  event->keyval == GDK_ISO_Enter))
+	{
+		handled = TRUE;
+		g_signal_emit (toolbar, signals[PREVIOUS], 0);
+	}
 
 	return handled;
 }
