@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-statusbar.c 6975 2007-03-24 23:09:11Z chpe $
+ *  $Id: ephy-statusbar.c 7033 2007-05-19 16:40:59Z chpe $
  */
 
 #include "config.h"
@@ -110,7 +110,7 @@ ephy_statusbar_size_allocate (GtkWidget *widget,
 
 	gstatusbar->label = label;
 }
-#endif /* GTK 2.11.0 */
+#endif /* !GTK 2.11.0 */
 
 static void
 ephy_statusbar_class_init (EphyStatusbarClass *klass)
